pub struct ZaiConfig {
pub enabled: bool,
pub api_key_env: String,
pub api_key: Option<String>,
pub plan_tier: Option<String>,
}Fields
enabled: boolapi_key_env: StringEnv var name to read the key from (env wins over api_key).
api_key: Option<String>Inline key (fallback when the env var is unset). Chmod 600 your config file if you put a real key here.
plan_tier: Option<String>Optional plan tier label (lite/pro/max) — display-only.