pub struct CredentialStore { /* private fields */ }Expand description
A file-backed credential store with an injectable path and owner policy.
Implementations
Sourceimpl CredentialStore
impl CredentialStore
pub fn at(path: impl Into<PathBuf>) -> Self
pub fn with_owner_provider( path: impl Into<PathBuf>, owner: Arc<dyn OwnerIdProvider>, ) -> Self
pub fn path(&self) -> &Path
pub fn lock_path(&self) -> PathBuf
pub fn acquire_lock(&self) -> Result<CredentialLock>
pub fn read(&self) -> Result<Option<CredentialDocument>>
pub fn write(&self, document: &CredentialDocument) -> Result<()>
Sourcepub fn write_locked(
&self,
lock: &CredentialLock,
document: &CredentialDocument,
) -> Result<()>
pub fn write_locked( &self, lock: &CredentialLock, document: &CredentialDocument, ) -> Result<()>
Replace a document while the caller holds this store’s exclusive lock. This is the seam used by the async refresh flow; it never performs an exchange after releasing the lock.
pub fn logout(&self) -> Result<()>
pub fn read_unlocked(&self) -> Result<Option<CredentialDocument>>