pub struct ContextState {
pub selected: usize,
pub detail: bool,
pub generation: u64,
pub load: ContextLoad,
/* private fields */
}Fields
selected: usizedetail: boolgeneration: u64load: ContextLoadImplementations
Sourceimpl ContextState
impl ContextState
Sourcepub fn begin_refresh(&mut self, generation: u64)
pub fn begin_refresh(&mut self, generation: u64)
Begin a scan with an identity allocated by the long-lived host app. The host, rather than this disposable overlay, owns monotonicity across close/reopen cycles.
Sourcepub fn apply_scan(
&mut self,
generation: u64,
result: Result<ContextScan, String>,
) -> bool
pub fn apply_scan( &mut self, generation: u64, result: Result<ContextScan, String>, ) -> bool
Ignore a result from an earlier r scan. The host also drops results
after the overlay closes by having no state to apply them to.
pub fn selected_session(&self) -> Option<&ContextSession>