pub struct AntigravityConfig {
pub enabled: bool,
}Expand description
Antigravity reads its quota from whichever local Antigravity product is running, so it needs no credentials — only an on/off switch.
Fields
enabled: boolTrait Implementations
Sourceimpl Clone for AntigravityConfig
impl Clone for AntigravityConfig
Sourcefn clone(&self) -> AntigravityConfig
fn clone(&self) -> AntigravityConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AntigravityConfig
impl Debug for AntigravityConfig
Sourceimpl Default for AntigravityConfig
impl Default for AntigravityConfig
Sourcefn default() -> AntigravityConfig
fn default() -> AntigravityConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AntigravityConfigwhere
AntigravityConfig: Default,
impl<'de> Deserialize<'de> for AntigravityConfigwhere
AntigravityConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more